@@ -19,6 +19,7 @@ from skimage import filters
 import time 
 from openTSNE import TSNE
 from sklearn.preprocessing import StandardScaler
+from torch_geometric.data.makedirs import makedirs
 
 
 def visualize_tsne_phenotypes(dataset, IndexAndClass,clusters):
@@ -75,18 +76,18 @@ def visualize_tsne_phenotypes(dataset, IndexAndClass,clusters):
             scatter = ax.scatter(embedding[:, 0],embedding[:, 1],s=0.5,c=pheno_assignmnents[:,ph],vmin=0,vmax=1,cmap='jet',edgecolors='none')        
             plt.title('TSNE of the dataset Phenoptype - '+str(ph+1), fontsize=24)    
             plt.colorbar(scatter)
-            plt.savefig(dataset.bioInsights_dir_cell_types_Pheno+'TSNE_embeddings_Ph_'+str(ph+1)+'.png',dpi=600)
+            plt.savefig(dataset.bioInsights_dir_cell_types_Pheno+'tSNE/'+'Ph_'+str(ph+1)+'.png',dpi=600)
 
         pheno_assignmnents_75 = np.zeros(pheno_assignmnents.shape[0])
         for ph in range(pheno_assignmnents.shape[1]):
-            thr = np.percentile(pheno_assignmnents[pheno_assignmnents.argmax(1)==ph,ph],75)
+            thr = np.percentile(pheno_assignmnents[pheno_assignmnents.argmax(1)==ph,ph],90)
             pheno_assignmnents_75[np.logical_and(pheno_assignmnents.argmax(1)==ph,pheno_assignmnents[:,ph]>=thr)] = ph+1
         plt.close('all')
         fig, ax = plt.subplots()   
         scatter = ax.scatter(embedding[:, 0],embedding[:, 1],s=0.5,c=pheno_assignmnents_75,cmap='jet',edgecolors='none')        
-        plt.title('TSNE of the dataset ALL_Phenotypes Q4', fontsize=24)    
+        plt.title('TSNE of the dataset ALL_Phenotypes D1', fontsize=24)    
         plt.colorbar(scatter)
-        plt.savefig(dataset.bioInsights_dir_cell_types_Pheno+'TSNE_embeddings_ALL_Phenotypes_Q4.png',dpi=600)
+        plt.savefig(dataset.bioInsights_dir_cell_types_Pheno+'tSNE/'+'ALL_Phenotypes_D1.png',dpi=600)        
 
 
     pat_num = int(len(IndexAndClass)*dataset.args['TSNE_Perc_Pat'])
@@ -106,9 +107,9 @@ def visualize_tsne_phenotypes(dataset, IndexAndClass,clusters):
     pheno_assignmnents = np.concatenate(pheno_assignmnents,axis=0)   
         
     # Create Tsne 
-    tsne_with_pheno_thrshold(dataset,features_idx,features,pheno_assignmnents)
+    makedirs(dataset.bioInsights_dir_cell_types_Pheno+'tSNE/')
+    embedding = tsne_with_pheno_thrshold(dataset,features_idx,features,pheno_assignmnents)
 
-    return
 
 def load_cell_types_assignments(dataset, cell_type_idx, subject_info,subgraph_idx,n_cell_types, prev_cell_type_assignment):
     """
@@ -155,7 +156,7 @@ def load_patch_image(dataset,imList):
     last_patch = 0
     for im_i in imList:
         num_patches = int(im_i.shape[0]/dataset.patch_size)*int(im_i.shape[1]/dataset.patch_size)
-        labels.append(np.transpose(np.reshape(np.array(range(last_patch,last_patch+num_patches)),(int(im_i.shape[0]/dataset.patch_size),int(im_i.shape[1]/dataset.patch_size)))))
+        labels.append(np.reshape(np.array(range(last_patch,last_patch+num_patches)),(int(im_i.shape[0]/dataset.patch_size),int(im_i.shape[1]/dataset.patch_size))))
         last_patch = last_patch+num_patches
 
     return np.concatenate(labels,1), labels
@@ -191,13 +192,11 @@ def select_patches_from_cohort_(clusters,dataset,subject_info,count):
                                                                     n_cell_types,prev_cell_type_assignment)                               
             # Open Single-Cell Contrastive Learning Information
             PCL_reprsntions = np.load(dataset.raw_dir+'/{}.npy'.format(subject_info[0]))                     
-            # Select Patches of a specific Phenotype and save its confidence
-            cell_type_top1 = np.apply_along_axis(np.argmax, axis=1, arr=cell_type_assignment) 
-            
+
             # Phenotypes and neighborhoods, or areas
             if cell_type_idx<2:             
                 # Select patches with most confidence
-                CropConfPheno,CropConfTissueComm = topk_confident_patches(dataset,n_cell_types,cell_type_top1,
+                CropConfPheno,CropConfTissueComm = topk_confident_patches(dataset,n_cell_types,
                                                                             cell_type_assignment,cell_type_idx,CropConfPheno,
                                                                             CropConfTissueComm,im,imList,PCL_reprsntions,count)  
             else:
@@ -205,7 +204,7 @@ def select_patches_from_cohort_(clusters,dataset,subject_info,count):
                 for c_type in range(n_cell_types):
                     TissueArea_Conf[c_type].append(cell_type_assignment[:,c_type])
 
-    del im, imList, PCL_reprsntions, cell_type_top1
+    del im, imList, PCL_reprsntions
     gc.collect(0)
     gc.collect(1)
     gc.collect(2)
@@ -253,7 +252,7 @@ def select_patches_from_cohort(dataset,IndexAndClass,clusters):
             
     return CropConfPheno,CropConfTissueComm, TissueArea_Conf
 
-def topk_confident_patches(dataset,n_cell_types,cell_type_top1,
+def topk_confident_patches(dataset,n_cell_types,
                             cell_type_assignment,cell_type_idx,CropConfPheno,
                             CropConfTissueComm,im,imList,PCL_reprsntions,count):
     '''
@@ -262,16 +261,16 @@ def topk_confident_patches(dataset,n_cell_types,cell_type_top1,
 
     # Create label map. 
     labels,labels_list = load_patch_image(dataset,imList)
-    for ll in range(len(labels_list)):
-        labels_list[ll] = np.transpose(labels_list[ll])
-    labels = np.concatenate(labels_list,axis=1)
+    # for ll in range(len(labels_list)):
+    #     labels_list[ll] = np.transpose(labels_list[ll])
+    # labels = np.concatenate(labels_list,axis=1)
 
             
     for c in range(n_cell_types):
                                                                         
         # Obtain patch info of the K with most certainty
-        highest_ent_patch = cell_type_assignment[np.where(cell_type_top1[:PCL_reprsntions.shape[0]]==c)[0],c].argsort()[-K:]
-        for patch_idx in np.where(cell_type_top1[:PCL_reprsntions.shape[0]]==c)[0][highest_ent_patch]:                  
+        highest_ent_patches = cell_type_assignment[:PCL_reprsntions.shape[0],c].argsort()[-K:]
+        for patch_idx in highest_ent_patches:                  
                     
             # Select the patch from the patch_image            
             mask = labels==patch_idx
@@ -335,29 +334,45 @@ def calculate_IoU_usingOtsu(matrix_0,matrix_1):
 
 def calculate_marker_colocalization(matrix,MarkerNames):
     # matrix: contains (number of patches, x_dimension, y_dimension, number of markers)
-    Marker_Colocalization =  np.zeros(len(list(itertools.combinations(MarkerNames,2))))
+    Marker_Colocalization =  np.ones((len(MarkerNames),len(MarkerNames)))
     for n_comb, pair_of_markers in enumerate(itertools.combinations(MarkerNames,2)):
         id_0 = MarkerNames.index(pair_of_markers[0])
         id_1 = MarkerNames.index(pair_of_markers[1])
         matrix_0 = matrix[:,:,:,[id_0]]
         matrix_1 = matrix[:,:,:,[id_1]]
         for n_patch in range(matrix.shape[0]):            
-            Marker_Colocalization[n_comb] += calculate_pearson_correlation(matrix_0[n_patch,:,:],matrix_1[n_patch,:,:])
+            Marker_Colocalization[id_0,id_1] += calculate_pearson_correlation(matrix_0[n_patch,:,:],matrix_1[n_patch,:,:])
+        Marker_Colocalization[id_1,id_0] = Marker_Colocalization[id_0,id_1]
     return Marker_Colocalization/matrix.shape[0]
 
 def calculate_Cell_Size_circularity(filename, matrix):
     # matrix: contains (number of patches, x_dimension, y_dimension)         
     # selem = disk(2)
-    Size_eccentricity = np.zeros((2))
-    for patch in range(matrix.shape[0]):
-        if matrix[patch,:,:].sum()>0 and (matrix[patch,:,:].max()-matrix[patch,:,:].min())>0:
-            logical = matrix[patch,:,:]>filters.threshold_otsu(matrix[patch,:,:]) 
-            # logical = opening(logical, selem)
-            Size_eccentricity[0] += logical.sum() # Area
-            Size_eccentricity[1] += min((4*3.14159*logical.sum())/(perimeter(logical,neighbourhood=4)**2),1) # Eccentricity
-            # if patch<4:
-            #     cv2.imwrite(filename+"Patch_"+str(patch)+"_Size_"+str(logical.sum())+"_Ecc_"+str((4*3.14159*logical.sum())/(perimeter(logical,neighbourhood=4)**2))+"_Raw.png", matrix[patch,:,:]/(matrix[patch,:,:].max())*255)
-            #     cv2.imwrite(filename+"Patch_"+str(patch)+"_Size_"+str(logical.sum())+"_Ecc_"+str((4*3.14159*logical.sum())/(perimeter(logical,neighbourhood=4)**2))+"_Logical.png", logical*255)
+    Size = np.zeros((matrix.shape[3]))
+    Eccentricity = np.zeros((matrix.shape[3]))
+    for mk in range(matrix.shape[3]):
+
+        # Calculate global threshold
+        thr = filters.threshold_otsu(matrix[:,:,:,mk])
+
+        # Initialize count
+        count = 0 
+
+        for patch in range(matrix.shape[0]):
+            
+            if matrix[patch,:,:].sum()>0 and (matrix[patch,:,:].max()-matrix[patch,:,:].min())>0:
+                logical = matrix[patch,:,:]>thr
+                Size_eccentricity[0] += logical.sum() # Area
+                Size_eccentricity[1] += min((4*3.14159*logical.sum())/(perimeter(logical,neighbourhood=4)**2),1) # Eccentricity
+
+                count += 1
+        
+        Size[mk] /= count
+        Eccentricity[mk] /= count
+
+                # if patch<4:
+                #     cv2.imwrite(filename+"Patch_"+str(patch)+"_Size_"+str(logical.sum())+"_Ecc_"+str((4*3.14159*logical.sum())/(perimeter(logical,neighbourhood=4)**2))+"_Raw.png", matrix[patch,:,:]/(matrix[patch,:,:].max())*255)
+                #     cv2.imwrite(filename+"Patch_"+str(patch)+"_Size_"+str(logical.sum())+"_Ecc_"+str((4*3.14159*logical.sum())/(perimeter(logical,neighbourhood=4)**2))+"_Logical.png", logical*255)
     return Size_eccentricity/matrix.shape[0]
 
 def extract_topk_patches_from_cohort(dataset, CropConf, Marker_Names,cell_type,Thresholds):
@@ -378,27 +393,25 @@ def extract_topk_patches_from_cohort(dataset, CropConf, Marker_Names,cell_type,T
     k=100
     topkPatches=[]
     # Create a heatmap marker using topk patches
-    heatmapMarkerExpression = np.zeros((7,len(CropConf),len(Marker_Names))) #Number of TMEs x number of markers
-    heatmap_Colocalization = np.zeros((len(CropConf),int(len(Marker_Names)*(len(Marker_Names)-1)/2))) # Number of TMEs x Number of Marker combinations
-    heatmap_CellSize_circularity = np.zeros((len(CropConf),2)) # Number of TMEs x (size and circularity)
+    heatmapMarkerExpression = np.zeros((7,len(CropConf),len(Marker_Names))) # Number of TMEs x number of markers
+    heatmap_Colocalization = np.zeros((len(CropConf),len(Marker_Names),len(Marker_Names))) # Number of TMEs x Number of Markers x Number of Markers
+    heatmap_CellSize_circularity = np.zeros((len(CropConf),2)) # size and circularity of markers
 
     # Use CropCOnf, that saves a lot of patches...
     for n_cell_type ,CropConf_i in enumerate(CropConf):
         
-        if len(CropConf_i)==0: # Let te heatmap be zero in case no ells were assigned to this TME.
+        if len(CropConf_i)==0: # Let te heatmap be zero in case no cells were assigned to this TME.
             continue
         
         # Choose patches with most confidence
-        topkPheno = np.array([CCP[1] for CCP in CropConf_i]).argsort()[-k:]        
+        topkPheno = np.array([CCP[1] for CCP in CropConf_i]).argsort()[-k:]               
+        
+        heatmap_Colocalization[n_cell_type,:,:] = calculate_marker_colocalization(np.array([CropConf_i[t][0] for t in topkPheno]),Marker_Names)    
+        heatmap_CellSize_circularity[n_cell_type,:] = calculate_Cell_Size_circularity(thisfolder,np.array([CropConf_i[t][0] for t in topkPheno]))
+
         # Save topkPheno to heatMarkerMap. Mean
         MarkerExpression = np.array([CropConf_i[t][0].mean((0,1)) for t in topkPheno])
         
-        # heatmap_Colocalization[n_cell_type,:] = calculate_marker_colocalization(MarkerExpression,Marker_Names)
-        # try:
-        #     heatmap_CellSize_circularity[n_cell_type,:] = calculate_Cell_Size_circularity(thisfolder,MarkerExpression[:,:,:,Marker_Names.index('DAPI')])
-        # except:
-        #     print('could not calculate cell size circularity because DAPI marker is missing')
-        
         # # Save marker expression of patches individually
         # if cell_type=='Phenotypes':        
         #     save_heatmap_with_names(thisfolder+'TME_{}_patchExpression.png'.format(n_cell_type+1),MarkerExpression.mean((1,2)),Marker_Names)            
@@ -408,8 +421,8 @@ def extract_topk_patches_from_cohort(dataset, CropConf, Marker_Names,cell_type,T
 
         # MarkerExpression = np.reshape(MarkerExpression,(MarkerExpression.shape[0]*MarkerExpression.shape[1]*MarkerExpression.shape[2],MarkerExpression.shape[3]))
         heatmapMarkerExpression[0,n_cell_type,:] = np.mean(MarkerExpression,axis=0)                    
-        for n_i, i in enumerate(Thresholds[1:]):
-            heatmapMarkerExpression[n_i+1,n_cell_type,:] = np.percentile(MarkerExpression,i,axis=0)                    
+        # for n_i, i in enumerate(Thresholds[1:]):
+        #     heatmapMarkerExpression[n_i+1,n_cell_type,:] = np.percentile(MarkerExpression,i,axis=0)                    
 
         # Save Image in RGB
         ImwithKPatches = np.zeros((dataset.patch_size*mult_1*int(np.sqrt(k))+mult_2*int(np.sqrt(k)),dataset.patch_size*mult_1*int(np.sqrt(k))+mult_2*int(np.sqrt(k)),CropConf_i[0][0].shape[2]))
@@ -621,7 +634,15 @@ def Area_to_Neighborhood_to_Phenotype(dataset,clusters,IndexAndClass, Clustering
     Area_to_Neigh[np.isnan(Area_to_Neigh)] = 0
     h_E_Fig = sns.clustermap(Area_to_Neigh.transpose(),col_cluster=True, row_cluster=True, col_colors=row_colors_Area,
                                 row_colors=col_colors_Neigh,yticklabels=xticklabels_Neigh,xticklabels=yticklabels_Area, linewidths=0.5, cmap="bwr")            
-    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'heatmap_Neighborhood_composition_of_Areas_Perc_'+str(ClusteringThreshold)+'.png',dpi=600) 
+    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types_Areas + 'heatmap_Neighborhood_composition_of_Areas_Perc_'+str(ClusteringThreshold)+'.png',dpi=600) 
+    plt.close('all')
+    plt.figure()
+    h_E_Fig = sns.clustermap(Area_to_Neigh.transpose(),col_cluster=True, row_cluster=True, col_colors=row_colors_Area, z_score=1,
+                                row_colors=col_colors_Neigh,yticklabels=xticklabels_Neigh,xticklabels=yticklabels_Area, linewidths=0.5, cmap="bwr")            
+    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types_Areas + 'heatmap_Neighborhood_composition_of_Areas_Zscore_'+str(ClusteringThreshold)+'.png',dpi=600) 
+    df = pd.DataFrame(Area_to_Neigh.transpose(), columns = yticklabels_Area)
+    df.index = xticklabels_Neigh
+    df.to_excel(dataset.bioInsights_dir_cell_types_Areas + 'heatmap_Neighborhood_composition_of_Areas_Zscore_'+str(ClusteringThreshold)+'.xlsx')  
 
     # Phenotypes to neighborhoods
     patch_to_neigh = np.concatenate(patch_to_neigh,0) # patches x neigh
@@ -647,5 +668,15 @@ def Area_to_Neighborhood_to_Phenotype(dataset,clusters,IndexAndClass, Clustering
     h_E_Fig = sns.clustermap(Neigh_to_Pheno.transpose(),col_cluster=True, row_cluster=True, col_colors=row_colors_Neigh,
                                 row_colors=col_colors_Pheno,yticklabels=xticklabels_Pheno,xticklabels=yticklabels_Neigh, linewidths=0.5, cmap="bwr")            
     h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Neighborhoods/heatmap_Phenotype_composition_of_neighborhoods_Perc_Thrs{}.png'.format(str(ClusteringThreshold)),dpi=600) 
+    plt.close('all')
+    plt.figure()
+    Neigh_to_Pheno[Neigh_to_Pheno==0] = 1e-16
+    h_E_Fig = sns.clustermap(Neigh_to_Pheno.transpose(),col_cluster=True, row_cluster=True, col_colors=row_colors_Neigh, z_score=1,
+                                row_colors=col_colors_Pheno,yticklabels=xticklabels_Pheno,xticklabels=yticklabels_Neigh, linewidths=0.5, cmap="bwr")            
+    h_E_Fig.savefig(dataset.bioInsights_dir_cell_types + 'Neighborhoods/heatmap_Phenotype_composition_of_neighborhoods_Zscore_Thrs{}.png'.format(str(ClusteringThreshold)),dpi=600) 
+    df = pd.DataFrame(Neigh_to_Pheno.transpose(), columns = yticklabels_Neigh)
+    df.index = xticklabels_Pheno
+    df.to_excel(dataset.bioInsights_dir_cell_types + 'Neighborhoods/heatmap_Phenotype_composition_of_neighborhoods_Perc_Thrs{}.xlsx'.format(str(ClusteringThreshold)))  
+
 
     
