@@ -244,7 +244,7 @@ class NaroNet:
         self.optimizer = Adam(self.model.parameters(), lr=self.args['lr'],weight_decay=self.args['weight_decay'],amsgrad=True,eps=1e-4) # Set Optimizer
         
         # Choose NaroNet's scheduler
-        self.scheduler = StepLR(self.optimizer, step_size=self.args['lr_decay_step_size'], gamma=self.args['lr_decay_factor'])
+        self.scheduler = StepLR(self.optimizer, step_size=self.args['epochs'], gamma=1) 
         
         # Assign the fold step.
         self.fold += 1
