@@ -55,110 +55,110 @@ import NaroNet
 import cv2
 import networkx as nx 
 
-class NARODataset(torch.utils.data.Dataset):
-    r"""Dataset base class for creating graph datasets.
-    See `here <https://pytorch-geometric.readthedocs.io/en/latest/notes/
-    create_dataset.html>`__ for the accompanying tutorial.
+# class NARODataset(torch.utils.data.Dataset):
+#     r"""Dataset base class for creating graph datasets.
+#     See `here <https://pytorch-geometric.readthedocs.io/en/latest/notes/
+#     create_dataset.html>`__ for the accompanying tutorial.
 
-    Args:
-        root (string): Root directory where the dataset should be saved.
-        transform (callable, optional): A function/transform that takes in an
-            :obj:`torch_geometric.data.Data` object and returns a transformed
-            version. The data object will be transformed before every access.
-            (default: :obj:`None`)
-        pre_transform (callable, optional): A function/transform that takes in
-            an :obj:`torch_geometric.data.Data` object and returns a
-            transformed version. The data object will be transformed before
-            being saved to disk. (default: :obj:`None`)
-        pre_filter (callable, optional): A function that takes in an
-            :obj:`torch_geometric.data.Data` object and returns a boolean
-            value, indicating whether the data object should be included in the
-            final dataset. (default: :obj:`None`)
-    """
+#     Args:
+#         root (string): Root directory where the dataset should be saved.
+#         transform (callable, optional): A function/transform that takes in an
+#             :obj:`torch_geometric.data.Data` object and returns a transformed
+#             version. The data object will be transformed before every access.
+#             (default: :obj:`None`)
+#         pre_transform (callable, optional): A function/transform that takes in
+#             an :obj:`torch_geometric.data.Data` object and returns a
+#             transformed version. The data object will be transformed before
+#             being saved to disk. (default: :obj:`None`)
+#         pre_filter (callable, optional): A function that takes in an
+#             :obj:`torch_geometric.data.Data` object and returns a boolean
+#             value, indicating whether the data object should be included in the
+#             final dataset. (default: :obj:`None`)
+#     """
 
-    @property
-    def raw_file_names(self):
-        r"""The name of the files to find in the :obj:`self.raw_dir` folder in
-        order to skip the download."""
-        raise NotImplementedError
+#     @property
+#     def raw_file_names(self):
+#         r"""The name of the files to find in the :obj:`self.raw_dir` folder in
+#         order to skip the download."""
+#         raise NotImplementedError
 
-    @property
-    def processed_file_names(self):
-        r"""The name of the files to find in the :obj:`self.processed_dir`
-        folder in order to skip the processing."""
-        raise NotImplementedError
+#     @property
+#     def processed_file_names(self):
+#         r"""The name of the files to find in the :obj:`self.processed_dir`
+#         folder in order to skip the processing."""
+#         raise NotImplementedError
 
-    def download(self):
-        r"""Downloads the dataset to the :obj:`self.raw_dir` folder."""
-        raise NotImplementedError
+#     def download(self):
+#         r"""Downloads the dataset to the :obj:`self.raw_dir` folder."""
+#         raise NotImplementedError
 
-    def process(self):
-        r"""Processes the dataset to the :obj:`self.processed_dir` folder."""
-        raise NotImplementedError
+#     def process(self):
+#         r"""Processes the dataset to the :obj:`self.processed_dir` folder."""
+#         raise NotImplementedError
 
-    def __len__(self):
-        r"""The number of examples in the dataset."""
-        raise NotImplementedError
+#     def __len__(self):
+#         r"""The number of examples in the dataset."""
+#         raise NotImplementedError
 
-    def get(self, idx):
-        r"""Gets the data object at index :obj:`idx`."""
-        raise NotImplementedError
+#     def get(self, idx):
+#         r"""Gets the data object at index :obj:`idx`."""
+#         raise NotImplementedError
 
-    def __init__(self,
-                 root,
-                 patch_size,
-                 recalculate,
-                 UseSuperpatch,
-                 transform=None,
-                 pre_transform=None,
-                 pre_filter=None):
-        super(NARODataset, self).__init__()
+#     def __init__(self,
+#                  root,
+#                  patch_size,
+#                  recalculate,
+#                  UseSuperpatch,
+#                  transform=None,
+#                  pre_transform=None,
+#                  pre_filter=None):
+#         super(NARODataset, self).__init__()
 
-        self.root = osp.expanduser(osp.normpath(root))
-        if UseSuperpatch:
-            self.raw_dir = osp.join(osp.join(self.root,'Patch_Contrastive_Learning'),'Image_Patch_Representation')
-        else:
-            self.raw_dir = osp.join(osp.join(self.root,'Patch_Contrastive_Learning'),'Image_Patch_Representation')
+#         self.root = osp.expanduser(osp.normpath(root))
+#         if UseSuperpatch:
+#             self.raw_dir = osp.join(osp.join(self.root,'Patch_Contrastive_Learning'),'Image_Patch_Representation')
+#         else:
+#             self.raw_dir = osp.join(osp.join(self.root,'Patch_Contrastive_Learning'),'Image_Patch_Representation')
 
-        self.processed_dir = osp.join(osp.join(self.root,'NaroNet'),'Enriched_graph_'+str(patch_size+1))
-        self.transform = transform
-        self.pre_transform = pre_transform
-        self.pre_filter = pre_filter
-        self.context_size = patch_size+1
-        self.recalculate = recalculate
-        self._process()
+#         self.processed_dir = osp.join(osp.join(self.root,'NaroNet'),'Enriched_graph_'+str(patch_size+1))
+#         self.transform = transform
+#         self.pre_transform = pre_transform
+#         self.pre_filter = pre_filter
+#         self.context_size = patch_size+1
+#         self.recalculate = recalculate
+#         self._process()
 
-    @property
-    def num_node_features(self):
-        data = get(0)
-        return data.num
+#     @property
+#     def num_node_features(self):
+#         data = get(0)
+#         return data.num
 
-    @property
-    def num_features(self):
-        r"""Alias for :py:attr:`~num_node_features`."""
-        return self.num_node_features
+#     @property
+#     def num_features(self):
+#         r"""Alias for :py:attr:`~num_node_features`."""
+#         return self.num_node_features
 
-    @property
-    def num_edge_features(self):
-        r"""Returns the number of features per edge in the dataset."""
-        return self[0].num_edge_features
+#     @property
+#     def num_edge_features(self):
+#         r"""Returns the number of features per edge in the dataset."""
+#         return self[0].num_edge_features
 
-    @property
-    def processed_paths(self):
-        r"""The filepaths to find in the :obj:`self.processed_dir`
-        folder in order to skip the processing."""
-        files = to_list(self.processed_file_names)
-        return [osp.join(self.processed_dir, f) for f in files]
+#     @property
+#     def processed_paths(self):
+#         r"""The filepaths to find in the :obj:`self.processed_dir`
+#         folder in order to skip the processing."""
+#         files = to_list(self.processed_file_names)
+#         return [osp.join(self.processed_dir, f) for f in files]
 
-    def __getitem__(self, idx):  # pragma: no cover
-        r"""Gets the data object at index :obj:`idx` and transforms it (in case
-        a :obj:`self.transform` is given)."""
-        data = self.get(idx)
-        data = data if self.transform is None else self.transform(data)
-        return data
+#     def __getitem__(self, idx):  # pragma: no cover
+#         r"""Gets the data object at index :obj:`idx` and transforms it (in case
+#         a :obj:`self.transform` is given)."""
+#         data = self.get(idx)
+#         data = data if self.transform is None else self.transform(data)
+#         return data
 
-    def __repr__(self):  # pragma: no cover
-        return '{}({})'.format(self.__class__.__name__, len(self))
+#     def __repr__(self):  # pragma: no cover
+#         return '{}({})'.format(self.__class__.__name__, len(self))
 
 class NaroNet_dataset(torch.utils.data.Dataset):
     '''
@@ -178,13 +178,14 @@ class NaroNet_dataset(torch.utils.data.Dataset):
         self.processed_dir = osp.join(osp.join(self.root,'NaroNet'),'_'.join(experiment_label))
         self.processed_dir_graphs = self.processed_dir+'/Subject_graphs/'
         self.processed_dir_cross_validation = self.processed_dir+'/Cross_validation_results/'
-        self.processed_dir_cell_types = self.processed_dir+'/Cell_type_assignment/'
+        self.processed_dir_cell_types = self.processed_dir+'/TMEs_assignment/'
         self.bioInsights_dir = self.root+'BioInsights/'+'_'.join(experiment_label)+'/'
-        self.bioInsights_dir_cell_types =  self.bioInsights_dir+'Cell_type_characterization/'
+        self.bioInsights_dir_cell_types =  self.bioInsights_dir+'TMEs_characterization/'
         self.bioInsights_dir_cell_types_Neigh =  self.bioInsights_dir_cell_types+'Neighborhoods/'
         self.bioInsights_dir_cell_types_Pheno =  self.bioInsights_dir_cell_types+'Phenotypes/'
+        self.bioInsights_dir_cell_types_Areas =  self.bioInsights_dir_cell_types+'Areas/'
         self.bioInsights_dir_cell_types_abundance =  self.bioInsights_dir+'Cell_type_abundance/'
-        self.bioInsights_dir_abundance_analysis =  self.bioInsights_dir+'Differential_abundance_analysis/'
+        self.bioInsights_dir_abundance_analysis =  self.bioInsights_dir+'TME_differential_abundance_analysis/'
         self.bioInsights_dir_abundance_analysis_global = self.bioInsights_dir_abundance_analysis+'GlobalAnalysis/'
         self.bioInsights_dir_TME_in_image =  self.bioInsights_dir+'Locate_TME_in_image/'                
         self.bioInsights_dir_abundance_analysis_Subgroups =  self.bioInsights_dir_abundance_analysis + 'Inter_Intra_Patient_Analysis/'
@@ -201,7 +202,8 @@ class NaroNet_dataset(torch.utils.data.Dataset):
         makedirs(self.bioInsights_dir_abundance_analysis)
         makedirs(self.bioInsights_dir_abundance_analysis_global)
         makedirs(self.bioInsights_dir_abundance_analysis_Subgroups)
-        makedirs(self.bioInsights_dir_TME_in_image)        
+        makedirs(self.bioInsights_dir_TME_in_image)    
+        makedirs(self.bioInsights_dir_cell_types_Areas)    
         self.process()
 
 
@@ -525,7 +527,6 @@ class NaroNet_dataset(torch.utils.data.Dataset):
  
             break
     def saveInductiveClusters(self,InductiveClusters, fileIndex, subImId, batch_id,args):
-        makedirs(osp.join(self.processed_dir,'ProcessedImages'))        
         np.save(self.processed_dir_cell_types+'cluster_assignmentPerPatch_Index_{}_{}_ClustLvl_{}.npy'.format(fileIndex, subImId, InductiveClusters[0].shape[-1]),torch.Tensor.cpu(InductiveClusters[0][batch_id,:]).detach().numpy())     
         np.save(self.processed_dir_cell_types+'cluster_assignmentPerPatch_Index_{}_{}_ClustLvl_{}.npy'.format(fileIndex, subImId, InductiveClusters[1].shape[-1]),torch.Tensor.cpu(InductiveClusters[1][batch_id,:]).detach().numpy())     
         
@@ -690,14 +691,13 @@ class NaroNet_dataset(torch.utils.data.Dataset):
                     shp = im.shape
                     im = np.moveaxis(im,0,2)                    
                 elif np.argmin(im.shape)==1:
-                    im = np.reshape(im,(im.shape[0]*im.shape[2],im.shape[1]))     
+                    im = np.moveaxis(im,1,2)      
                 
                 # Choose user-defined channels
                 im = im[:,:,Channels] 
 
                 # Cut im
                 im = im[:int(im.shape[0]/self.patch_size)*self.patch_size,:int(im.shape[1]/self.patch_size)*self.patch_size,:]   
-                im = np.transpose(im, axes=(1,0,2))
                 
                 # Append to list of images
                 imList.append(im)
@@ -993,7 +993,7 @@ class NaroNet_dataset(torch.utils.data.Dataset):
         if self.args['TSNE_Perc_Pat']>0:
             visualize_tsne_phenotypes(self, IndexAndClass,clusters)
 
-        CropConfPheno, CropConfTissueComm, TissueArea_Conf = select_patches_from_cohort(self,IndexAndClass,clusters)                 
+        CropConfPheno, CropConfTissueComm, TissueArea_Conf = select_patches_from_cohort(self,IndexAndClass[:int(self.args['Pheno_Perc_Pat']*len(IndexAndClass))],clusters)                 
         
         Channels, Marker_Names = utilz.load_channels(self.root+'Raw_Data/')
 
@@ -1014,17 +1014,17 @@ class NaroNet_dataset(torch.utils.data.Dataset):
         '''
 
         # Obtain Neigh-to-Pheno, and Area-to-Neigh heatmap.
-        for ClusteringTrheshold in [0,50,75,90,99,99.9,99.99]:
-            Area_to_Neighborhood_to_Phenotype(self,clusters,IndexAndClass,ClusteringTrheshold)     
+        # for ClusteringTrheshold in [0,50,75,90,99]:
+        #     Area_to_Neighborhood_to_Phenotype(self,clusters,IndexAndClass,ClusteringTrheshold)     
 
         # Obtain cell-types examples
         self.ObtainPhenoExamples(IndexAndClass,clusters,[25])                
         
-        # Cell-types abundances
-        heatmapClusterPresence, labels = self.clusterPresence(clusters, IndexAndClass,[50], isTraining=False)                        
+        # # Cell-types abundances
+        # heatmapClusterPresence, labels = self.clusterPresence(clusters, IndexAndClass,[50], isTraining=False)                        
         
-        # Differential abundance analysis
-        _, _, _, _, _ = differential_abundance_analysis(self, heatmapClusterPresence, labels, IndexAndClass,False)
+        # # Differential abundance analysis
+        # _, _, _, _, _ = differential_abundance_analysis(self, heatmapClusterPresence, labels, IndexAndClass,False)
 
         # Apply clusters and attention to images
         All_TMEs_in_Image(self, clusters, IndexAndClass)        
