@@ -40,7 +40,7 @@ def patch_contrastive_learning(args):
 
     # Train patch contrastive learning 
     simclr = SimCLR(model=model, optimizer=optimizer, scheduler=scheduler, args=args)
-    if len([f for f in os.listdir(simclr.model_dir) if f.endswith('.tar')]) == 0:
+    if len([f for f in os.listdir(simclr.model_dir) if f.endswith('.tar')]) < 10:
         simclr.train(train_loader)
 
     # Infer model to get embeddings
